@@ -1,22 +1,10 @@
-/*****************************************************************************
- * Copyright (c) 2007 Andreas Pakulat <apaku@gmx.de>                         *
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright (c) 2012-2016 Sven Brauch <svenbrauch@gmail.com>                *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2012-2016 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pythonlanguagesupport.h"
 
@@ -68,16 +56,16 @@ K_PLUGIN_FACTORY_WITH_JSON( KDevPythonSupportFactory, "kdevpythonsupport.json",
 
 namespace Python
 {
-LanguageSupport* LanguageSupport::m_self = 0;
+LanguageSupport* LanguageSupport::m_self = nullptr;
 
-KDevelop::ContextMenuExtension LanguageSupport::contextMenuExtension(KDevelop::Context* context)
+ContextMenuExtension LanguageSupport::contextMenuExtension(Context* context, QWidget* parent)
 {
     ContextMenuExtension cm;
     EditorContext *ec = dynamic_cast<KDevelop::EditorContext *>(context);
 
     if (ec && ICore::self()->languageController()->languagesForUrl(ec->url()).contains(this)) {
         // It's a Python file, let's add our context menu.
-        m_refactoring->fillContextMenu(cm, context);
+        m_refactoring->fillContextMenu(cm, context, parent);
         TypeCorrection::self().doContextMenu(cm, context);
     }
     return cm;
@@ -127,7 +115,7 @@ LanguageSupport::~LanguageSupport()
     parseLock()->unlock();
 
     delete m_highlighting;
-    m_highlighting = 0;
+    m_highlighting = nullptr;
 }
 
 KDevelop::ParseJob *LanguageSupport::createParseJob( const IndexedString& url )
@@ -153,7 +141,8 @@ SourceFormatterItemList LanguageSupport::sourceFormatterItems() const
     autopep8.setOverrideSample("class klass:\n def method(arg1,arg2):\n  a=3+5\n"
                                "def function(arg,*vararg,**kwargs): return arg+kwarg[0]\nfunction(3, 5, 7)");
     using P = SourceFormatterStyle::MimeHighlightPair;
-    autopep8.setMimeTypes(SourceFormatterStyle::MimeList{ P{"text/x-python", "Python"} });
+    autopep8.setMimeTypes(SourceFormatterStyle::MimeList{ P{"text/x-python", "Python"},
+                                                          P{"text/x-python3", "Python 3"} });
     QString autopep8path = QStandardPaths::findExecutable("autopep8");
     if (autopep8path.isEmpty()) {
         // TODO: proper error handling/user notification
